@@ -1,4 +1,4 @@
-/* Copyright (C) 2008 G.P. Halkes
+/* Copyright (C) 2008-2010 G.P. Halkes
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 3, as
    published by the Free Software Foundation.
@@ -25,6 +25,6 @@ typedef struct {
 	char name[TEMPLATE_LENGTH];
 } TempFile;
 
-TempFile *tempFile(void);
+TempFile *tempFile(int depth);
 
 #endif
